@@ -211,91 +211,78 @@ class DBConnect:
             checking = parameter.param_url
         else:
             checking = parameter.param_json
-        # offset表示当前页第一条在记录集中的位置，接收即可，无需处理
         param = parameter.verification(
             checking=checking,
             verify={
-                'limit': int, 'current': int, 'select_list': list, 'orderby_list': list,
-                'filter_list': list, 'start_date': str, 'end_date': str, 'date_type': str,
-                'offset': int,
+                '$limit': int, '$offset': int, '$orderby': str, '$start_date': str, '$date_type': str,
+                '$end_date': str,
             },
-            optional={'start_date': '', 'end_date': '', 'date_type': 'update_time', 'offset': 0})
+            optional={'$start_date': '', '$end_date': '', '$date_type': 'update_time', '$offset': 0, '$limit': 10, '$orderby': ''})
         try:
-            limit = int(param['limit'])  # 每页条数
-            current = int(param['current'])  # 当前页数
-            if current < 1 or limit < 1:
-                raise Exception('当前页数和每页条数都从 1 开始计算')
-            else:
-                current -= 1
-            select_list = param['select_list']  # 受控列
-            # 排序顺序（对应受控列），asc=升序，desc=降序
-            orderby_list = param['orderby_list']
-            # 筛选值（对应受控列）
-            filter_list = param['filter_list']
-            start_date = handle_date(date=param['start_date'])  # 可选——开始日期
+            limit = int(param['$limit'])  # 指示页大小（从1开始）
+            offset = int(param['$offset'])  # 指示记录起始位置（从0开始）
+            if limit < 1:
+                raise Exception('指示页大小必须从 1 开始计算')
+            # 排序规则（`key1 desc,key2 asc`），asc=升序，desc=降序
+            orderby = param['$orderby']
+            sort_list = []  # 数据库排序规则列表
+            if orderby:
+                # 整理请求参数中的筛排序列表
+                orderby = orderby.split(',')
+                for order in orderby:
+                    order_kv = order.split(' ')
+                    if len(order_kv) == 2 and (order_kv[1] == 'asc' or order_kv[1] == 'desc') and order_kv[0].strip() != '':
+                        if order_kv[1] == 'asc':
+                            sort_list.append((order_kv[0], pymongo.ASCENDING))
+                        elif order_kv[1] == 'desc':
+                            sort_list.append((order_kv[0], pymongo.DESCENDING))
+                    else:
+                        raise Exception(
+                            '排序参数不符合格式要求: "{0}"'.format(param['$orderby']))
+            start_date = handle_date(date=param['$start_date'])  # 可选——开始日期
             # 可选——结束日期，与开始日期组成日期区间
-            end_date = handle_date(date=param['end_date'], date_type='end')
-            if len(select_list) != len(orderby_list) or len(select_list) != len(filter_list):
-                raise Exception('三个控制列表的长度不一致')
+            end_date = handle_date(date=param['$end_date'], date_type='end')
             # 查找假删除数据的数据量
             remove_count = self.mongo_collection.find(
                 {'remove_time': {'$exists': True}}).count()
             # 查找字典和排序列表，处理假删除数据
             find_dict = handle_db_remove({})
-            sort_list = []
-            if len(select_list):
-                for i in range(len(select_list)):
-                    # 整理请求参数中的筛选项字典
-                    if type(filter_list[i]) == int:
-                        find_dict[select_list[i]] = filter_list[i]
-                    elif select_list[i] == 'id' or select_list[i] == '_id':
-                        find_dict['_id'] = ObjectId(str(filter_list[i]))
-                    else:
-                        if filter_list[i].strip() != '':
-                            find_dict[select_list[i]] = {
-                                '$regex': filter_list[i]}
-                    # 整理请求参数中的筛排序列表
-                    if type(orderby_list[i]) != str:
-                        abort(Response('计算组件分页参数异常: 排序参数不支持 int 类型', 400, {}))
-                    sort_value = orderby_list[i].strip()
-                    if sort_value == 'asc':
-                        sort_list.append((select_list[i], pymongo.ASCENDING))
-                    elif sort_value == 'desc':
-                        sort_list.append((select_list[i], pymongo.DESCENDING))
-                    elif sort_value == '':
-                        pass
-                    else:
-                        abort(Response('计算组件分页参数异常: 仅支持 asc 和 desc 两个值', 400, {}))
+            redundant_filter = param['redundant_dict']  # 额外的数据库筛选字典
+            for filter_key, filter_value in redundant_filter.items():
+                # 整理请求参数中的筛选项字典
+                if type(filter_value) == int:
+                    find_dict[filter_key] = filter_value
+                elif filter_key == 'id' or filter_key == '_id':
+                    find_dict['_id'] = ObjectId(str(filter_value))
+                else:
+                    if filter_value.strip() != '':
+                        find_dict[filter_key] = {'$regex': filter_value}
             # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
             if start_date and end_date:
-                find_dict[param['date_type']] = {
+                find_dict[param['$date_type']] = {
                     '$gte': start_date, '$lte': end_date}
             # 对排序规则处理
             if sort_list:
                 find_data = self.mongo_collection.find(find_dict).sort(sort_list).limit(
-                    limit).skip(limit * current)
+                    limit).skip(offset)
             else:
                 find_data = self.mongo_collection.find(find_dict).limit(
-                    limit).skip(limit * current)
+                    limit).skip(offset)
             # 处理返回数据
             records_filtered = find_data.count()
             # 判断数据是否为空
-            if find_data.count():
+            if records_filtered:
                 # 处理返回数据
                 query_result = handle_db_to_list(find_data)
                 return {
-                    'total': self.mongo_collection.estimated_document_count() - remove_count,
-                    'filtered': records_filtered,
+                    'total': records_filtered,
                     'items': query_result,
-                    'pages': math.ceil(records_filtered / limit),
                     'dummy_remove': remove_count,
                 }
             else:
                 return {
-                    'total': self.mongo_collection.estimated_document_count() - remove_count,
-                    'filtered': 0,
+                    'total': 0,
                     'items': [],
-                    'pages': 0,
                     'dummy_remove': remove_count,
                 }
         except Exception as err:
