@@ -98,8 +98,8 @@ class VerifyToken:
                     if self.role_db:
                         # 添加权限集合信息到角色集合
                         for status in (0, 1, 2, 3):
-                            permissions_set = {
-                                'permission_status': status}.update(find_dict)
+                            permissions_set = find_dict.update(
+                                {'permission_status': status})
                             if not self.role_db.does_it_exist(permissions_set):
                                 permissions_set.update(
                                     {'permission_id': purview_name_id})
@@ -147,8 +147,8 @@ class VerifyToken:
                 permission_status = int(roles[0]['permission_status'])
         if permission_status == 0:
             handle_abnormal(
-                message='无 "{0}-{1}" 的访问权限'.format(
-                    center_name, permission_name),
+                message='无 "{0}-{1}" 的访问权限({2})'.format(
+                    center_name, permission_name, permission_status),
                 status=401,
             )
         return permission_status
